==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/FileTypeGenParametersFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link FileTypeGenParameters}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class FileTypeGenParametersFieldAttributes extends AbstractBeanAttributesDefinition{

    /** fileType (Database column: FILE_TYPE_ID) */
    static public AttributeDefinition fileType =
        new AttributeDefinition("fileType")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("FILE_TYPE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class);

    /** help (Database column: HELP) */
    static public AttributeDefinition help =
        new AttributeDefinition("help")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("HELP")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** hint (Database column: HINT) */
    static public AttributeDefinition hint =
        new AttributeDefinition("hint")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("HINT")
                .setMandatory(true)
                .setMaxSize(1000)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** isMandatory (Database column: IS_MANDATORY) */
    static public AttributeDefinition isMandatory =
        new AttributeDefinition("isMandatory")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("IS_MANDATORY")
                .setMandatory(true)
                .setMaxSize(255)
                .setDefaultValue("1")
                .setType(boolean.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** options (Database column: OPTIONS) */
    static public AttributeDefinition options =
        new AttributeDefinition("options")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("OPTIONS")
                .setMandatory(true)
                .setMaxSize(4000)
                .setType(String.class);

    /** optionsAjaxEvent (Database column: OPTIONS_AJAX_EVENT) */
    static public AttributeDefinition optionsAjaxEvent =
        new AttributeDefinition("optionsAjaxEvent")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("OPTIONS_AJAX_EVENT")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** type (Database column: TYPE) */
    static public AttributeDefinition type =
        new AttributeDefinition("type")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("TYPE")
                .setMandatory(true)
                .setMaxSize(30)
                .setType(String.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(fileType.getName(),fileType);
        map.put(help.getName(),help);
        map.put(hint.getName(),hint);
        map.put(id.getName(),id);
        map.put(isMandatory.getName(),isMandatory);
        map.put(name.getName(),name);
        map.put(options.getName(),options);
        map.put(optionsAjaxEvent.getName(),optionsAjaxEvent);
        map.put(type.getName(),type);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/FileTypeGenParametersFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link FileTypeGenParameters}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class FileTypeGenParametersFieldAttributes extends AbstractBeanAttributesDefinition{

    /** fileType (Database column: FILE_TYPE_ID) */
    static public AttributeDefinition fileType =
        new AttributeDefinition("fileType")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("FILE_TYPE_ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("name")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.FileType.class);

    /** help (Database column: HELP) */
    static public AttributeDefinition help =
        new AttributeDefinition("help")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("HELP")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** hint (Database column: HINT) */
    static public AttributeDefinition hint =
        new AttributeDefinition("hint")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("HINT")
                .setMandatory(false)
                .setMaxSize(1000)
                .setType(String.class);

    /** id (Database column: ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(22)
                .setType(Long.class);

    /** isMandatory (Database column: IS_MANDATORY) */
    static public AttributeDefinition isMandatory =
        new AttributeDefinition("isMandatory")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("IS_MANDATORY")
                .setMandatory(false)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setDefaultValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** name (Database column: NAME) */
    static public AttributeDefinition name =
        new AttributeDefinition("name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("NAME")
                .setMandatory(true)
                .setMaxSize(500)
                .setType(String.class);

    /** options (Database column: OPTIONS) */
    static public AttributeDefinition options =
        new AttributeDefinition("options")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("OPTIONS")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** optionsAjaxEvent (Database column: OPTIONS_AJAX_EVENT) */
    static public AttributeDefinition optionsAjaxEvent =
        new AttributeDefinition("optionsAjaxEvent")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("OPTIONS_AJAX_EVENT")
                .setMandatory(false)
                .setMaxSize(500)
                .setType(String.class);

    /** type (Database column: TYPE) */
    static public AttributeDefinition type =
        new AttributeDefinition("type")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("FILE_TYPE_GEN_PARAMETERS")
                .setDatabaseId("TYPE")
                .setMandatory(true)
                .setMaxSize(30)
                .setType(String.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(fileType.getName(),fileType);
        map.put(help.getName(),help);
        map.put(hint.getName(),hint);
        map.put(id.getName(),id);
        map.put(isMandatory.getName(),isMandatory);
        map.put(name.getName(),name);
        map.put(options.getName(),options);
        map.put(optionsAjaxEvent.getName(),optionsAjaxEvent);
        map.put(type.getName(),type);

        return map;
    }
}
